==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-problem-mgmt/dictionaries/hu.dict.itop-problem-mgmt.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('HU HU', 'Hungarian', 'Magyar', [
	'Class:Problem' => 'Probléma',
	'Class:Problem+' => '',
	'Class:Problem/Attribute:assignment_date' => 'Megbízási dátum',
	'Class:Problem/Attribute:assignment_date+' => '',
	'Class:Problem/Attribute:impact' => 'Hatása',
	'Class:Problem/Attribute:impact+' => '',
	'Class:Problem/Attribute:impact/Value:1' => 'Felhasználókra',
	'Class:Problem/Attribute:impact/Value:1+' => '',
	'Class:Problem/Attribute:impact/Value:2' => 'Szolgáltatásokra',
	'Class:Problem/Attribute:impact/Value:2+' => '',
	'Class:Problem/Attribute:impact/Value:3' => 'Szervezeti egységre',
	'Class:Problem/Attribute:impact/Value:3+' => '',
	'Class:Problem/Attribute:knownerrors_list' => 'Ismert hibák',
	'Class:Problem/Attribute:knownerrors_list+' => '',
	'Class:Problem/Attribute:priority' => 'Prioritás',
	'Class:Problem/Attribute:priority+' => '',
	'Class:Problem/Attribute:priority/Value:1' => 'Kritikus',
	'Class:Problem/Attribute:priority/Value:1+' => '',
	'Class:Problem/Attribute:priority/Value:2' => 'Magas',
	'Class:Problem/Attribute:priority/Value:2+' => '',
	'Class:Problem/Attribute:priority/Value:3' => 'Közepes',
	'Class:Problem/Attribute:priority/Value:3+' => '',
	'Class:Problem/Attribute:priority/Value:4' => 'Alacsony',
	'Class:Problem/Attribute:priority/Value:4+' => '',
	'Class:Problem/Attribute:product' => 'Termék',
	'Class:Problem/Attribute:product+' => '',
	'Class:Problem/Attribute:related_change_id' => 'Kapcsolódó változások',
	'Class:Problem/Attribute:related_change_id+' => '',
	'Class:Problem/Attribute:related_change_ref' => 'Referenciaszám',
	'Class:Problem/Attribute:related_change_ref+' => '',
	'Class:Problem/Attribute:related_incident_list' => 'Kapcsolódó incidensek',
	'Class:Problem/Attribute:related_incident_list+' => 'Ehhez az incidenshez kapcsolódó problémák',
	'Class:Problem/Attribute:related_request_list' => 'Kapcsolódó kérelmek',
	'Class:Problem/Attribute:related_request_list+' => 'Ehhez a kérelemhez kapcsolódó problémák',
	'Class:Problem/Attribute:resolution_date' => 'Megoldási dátum',
	'Class:Problem/Attribute:resolution_date+' => '',
	'Class:Problem/Attribute:service_id' => 'Szolgáltatás',
	'Class:Problem/Attribute:service_id+' => '',
	'Class:Problem/Attribute:service_name' => 'Szolgáltatás név',
	'Class:Problem/Attribute:service_name+' => '',
	'Class:Problem/Attribute:servicesubcategory_id' => 'Szolgáltatáskategória',
	'Class:Problem/Attribute:servicesubcategory_id+' => '',
	'Class:Problem/Attribute:servicesubcategory_name' => 'Kategória név',
	'Class:Problem/Attribute:servicesubcategory_name+' => '',
	'Class:Problem/Attribute:status' => 'Állapot',
	'Class:Problem/Attribute:status+' => '',
	'Class:Problem/Attribute:status/Value:assigned' => 'Hozzárendelt',
	'Class:Problem/Attribute:status/Value:assigned+' => '',
	'Class:Problem/Attribute:status/Value:closed' => 'Lezárt',
	'Class:Problem/Attribute:status/Value:closed+' => '',
	'Class:Problem/Attribute:status/Value:new' => 'Új',
	'Class:Problem/Attribute:status/Value:new+' => '',
	'Class:Problem/Attribute:status/Value:resolved' => 'Megoldott',
	'Class:Problem/Attribute:status/Value:resolved+' => '',
	'Class:Problem/Attribute:urgency' => 'Sürgősség',
	'Class:Problem/Attribute:urgency+' => '',
	'Class:Problem/Attribute:urgency/Value:1' => 'Nem várhat',
	'Class:Problem/Attribute:urgency/Value:1+' => '',
	'Class:Problem/Attribute:urgency/Value:2' => 'Nagyon sürgős',
	'Class:Problem/Attribute:urgency/Value:2+' => '',
	'Class:Problem/Attribute:urgency/Value:3' => 'Sürgős',
	'Class:Problem/Attribute:urgency/Value:3+' => '',
	'Class:Problem/Attribute:urgency/Value:4' => 'Nem sürgős',
	'Class:Problem/Attribute:urgency/Value:4+' => '',
	'Class:Problem/Stimulus:ev_assign' => 'Hozzárendelés',
	'Class:Problem/Stimulus:ev_assign+' => '',
	'Class:Problem/Stimulus:ev_close' => 'Lezárás',
	'Class:Problem/Stimulus:ev_close+' => '',
	'Class:Problem/Stimulus:ev_reassign' => 'Újra hozzárendelés',
	'Class:Problem/Stimulus:ev_reassign+' => '',
	'Class:Problem/Stimulus:ev_resolve' => 'Megoldás',
	'Class:Problem/Stimulus:ev_resolve+' => '',
	'Menu:NewProblem' => 'Új probléma',
	'Menu:NewProblem+' => '',
	'Menu:Problem:MyProblems' => 'Saját problémák',
	'Menu:Problem:MyProblems+' => '',
	'Menu:Problem:OpenProblems' => 'Nyitott problémák',
	'Menu:Problem:OpenProblems+' => '',
	'Menu:Problem:Overview' => 'Áttekintő',
	'Menu:Problem:Overview+' => '',
	'Menu:Problem:Shortcuts' => 'Gyorsgombok',
	'Menu:ProblemManagement' => 'Problémakezelés',
	'Menu:ProblemManagement+' => '',
	'Menu:SearchProblems' => 'Problémák keresése',
	'Menu:SearchProblems+' => '',
	'UI-ProblemManagementOverview-ProblemByPriority' => 'Problémák prioritás szerint',
	'UI-ProblemManagementOverview-ProblemByPriority+' => '',
	'UI-ProblemManagementOverview-ProblemByService' => 'Problémák szolgáltatásonként',
	'UI-ProblemManagementOverview-ProblemByService+' => '',
	'UI-ProblemManagementOverview-ProblemUnassigned' => 'Nem hozzárendelt problémák',
	'UI-ProblemManagementOverview-ProblemUnassigned+' => '',
	'UI:ProblemMgmtMenuOverview:Title' => 'Problémakezelés műszerfal',
	'UI:ProblemMgmtMenuOverview:Title+' => '',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-problem-mgmt/dictionaries/hu.dict.itop-problem-mgmt.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('HU HU', 'Hungarian', 'Magyar', array(
	'Menu:ProblemManagement' => 'Problémakezelés',
	'Menu:ProblemManagement+' => '',
	'Menu:Problem:Overview' => 'Áttekintő',
	'Menu:Problem:Overview+' => '',
	'Menu:NewProblem' => 'Új probléma',
	'Menu:NewProblem+' => '',
	'Menu:SearchProblems' => 'Problémák keresése',
	'Menu:SearchProblems+' => '',
	'Menu:Problem:Shortcuts' => 'Gyorsgombok',
	'Menu:Problem:MyProblems' => 'Saját problémák',
	'Menu:Problem:MyProblems+' => '',
	'Menu:Problem:OpenProblems' => 'Nyitott problémák',
	'Menu:Problem:OpenProblems+' => '',
	'UI-ProblemManagementOverview-ProblemByService' => 'Problémák szolgáltatásonként',
	'UI-ProblemManagementOverview-ProblemByService+' => '',
	'UI-ProblemManagementOverview-ProblemByPriority' => 'Problémák prioritás szerint',
	'UI-ProblemManagementOverview-ProblemByPriority+' => '',
	'UI-ProblemManagementOverview-ProblemUnassigned' => 'Nem hozzárendelt problémák',
	'UI-ProblemManagementOverview-ProblemUnassigned+' => '',
	'UI:ProblemMgmtMenuOverview:Title' => 'Problémakezelés műszerfal',
	'UI:ProblemMgmtMenuOverview:Title+' => '',

));
//
// Class: Problem
//

Dict::Add('HU HU', 'Hungarian', 'Magyar', array(
	'Class:Problem' => 'Probléma',
	'Class:Problem+' => '',
	'Class:Problem/Attribute:status' => 'Állapot',
	'Class:Problem/Attribute:status+' => '',
	'Class:Problem/Attribute:status/Value:new' => 'Új',
	'Class:Problem/Attribute:status/Value:new+' => '',
	'Class:Problem/Attribute:status/Value:assigned' => 'Hozzárendelt',
	'Class:Problem/Attribute:status/Value:assigned+' => '',
	'Class:Problem/Attribute:status/Value:resolved' => 'Megoldott',
	'Class:Problem/Attribute:status/Value:resolved+' => '',
	'Class:Problem/Attribute:status/Value:closed' => 'Lezárt',
	'Class:Problem/Attribute:status/Value:closed+' => '',
	'Class:Problem/Attribute:service_id' => 'Szolgáltatás',
	'Class:Problem/Attribute:service_id+' => '',
	'Class:Problem/Attribute:service_name' => 'Szolgáltatás név',
	'Class:Problem/Attribute:service_name+' => '',
	'Class:Problem/Attribute:servicesubcategory_id' => 'Szolgáltatáskategória',
	'Class:Problem/Attribute:servicesubcategory_id+' => '',
	'Class:Problem/Attribute:servicesubcategory_name' => 'Kategória név',
	'Class:Problem/Attribute:servicesubcategory_name+' => '',
	'Class:Problem/Attribute:product' => 'Termék',
	'Class:Problem/Attribute:product+' => '',
	'Class:Problem/Attribute:impact' => 'Hatása',
	'Class:Problem/Attribute:impact+' => '',
	'Class:Problem/Attribute:impact/Value:1' => 'Felhasználókra',
	'Class:Problem/Attribute:impact/Value:1+' => '',
	'Class:Problem/Attribute:impact/Value:2' => 'Szolgáltatásokra',
	'Class:Problem/Attribute:impact/Value:2+' => '',
	'Class:Problem/Attribute:impact/Value:3' => 'Szervezeti egységre',
	'Class:Problem/Attribute:impact/Value:3+' => '',
	'Class:Problem/Attribute:urgency' => 'Sürgősség',
	'Class:Problem/Attribute:urgency+' => '',
	'Class:Problem/Attribute:urgency/Value:1' => 'Nem várhat',
	'Class:Problem/Attribute:urgency/Value:1+' => '',
	'Class:Problem/Attribute:urgency/Value:2' => 'Nagyon sürgős',
	'Class:Problem/Attribute:urgency/Value:2+' => '',
	'Class:Problem/Attribute:urgency/Value:3' => 'Sürgős',
	'Class:Problem/Attribute:urgency/Value:3+' => '',
	'Class:Problem/Attribute:urgency/Value:4' => 'Nem sürgős',
	'Class:Problem/Attribute:urgency/Value:4+' => '',
	'Class:Problem/Attribute:priority' => 'Prioritás',
	'Class:Problem/Attribute:priority+' => '',
	'Class:Problem/Attribute:priority/Value:1' => 'Kritikus',
	'Class:Problem/Attribute:priority/Value:1+' => '',
	'Class:Problem/Attribute:priority/Value:2' => 'Magas',
	'Class:Problem/Attribute:priority/Value:2+' => '',
	'Class:Problem/Attribute:priority/Value:3' => 'Közepes',
	'Class:Problem/Attribute:priority/Value:3+' => '',
	'Class:Problem/Attribute:priority/Value:4' => 'Alacsony',
	'Class:Problem/Attribute:priority/Value:4+' => '',
	'Class:Problem/Attribute:related_change_id' => 'Kapcsolódó változások',
	'Class:Problem/Attribute:related_change_id+' => '',
	'Class:Problem/Attribute:related_change_ref' => 'Referenciaszám',
	'Class:Problem/Attribute:related_change_ref+' => '',
	'Class:Problem/Attribute:assignment_date' => 'Megbízási dátum',
	'Class:Problem/Attribute:assignment_date+' => '',
	'Class:Problem/Attribute:resolution_date' => 'Megoldási dátum',
	'Class:Problem/Attribute:resolution_date+' => '',
	'Class:Problem/Attribute:knownerrors_list' => 'Ismert hibák',
	'Class:Problem/Attribute:knownerrors_list+' => '',
	'Class:Problem/Attribute:related_request_list' => 'Kapcsolódó kérelmek',
	'Class:Problem/Attribute:related_request_list+' => 'Ehhez a kérelemhez kapcsolódó problémák',
	'Class:Problem/Attribute:related_incident_list' => 'Kapcsolódó incidensek',
	'Class:Problem/Attribute:related_incident_list+' => 'Ehhez az incidenshez kapcsolódó problémák',
	'Class:Problem/Stimulus:ev_assign' => 'Hozzárendelés',
	'Class:Problem/Stimulus:ev_assign+' => '',
	'Class:Problem/Stimulus:ev_reassign' => 'Újra hozzárendelés',
	'Class:Problem/Stimulus:ev_reassign+' => '',
	'Class:Problem/Stimulus:ev_resolve' => 'Megoldás',
	'Class:Problem/Stimulus:ev_resolve+' => '',
	'Class:Problem/Stimulus:ev_close' => 'Lezárás',
	'Class:Problem/Stimulus:ev_close+' => '',
));
